@@ -1,3 +1,5 @@
+import re
+
 try:
     # Python 3
     from urllib.parse import quote_plus
@@ -18,13 +20,13 @@ def get_groups():
 def status(guid):
     return '{base_url}/deviceStatus/{guid}'.format(
         base_url=BASE_URL,
-        guid=quote_plus(guid).replace('%2f', 'f')
+        guid=re.sub('(?i)\%2f', 'f', quote_plus(guid))
     )
 
 def statusCache(guid):
     return '{base_url}/deviceStatus/now/{guid}'.format(
         base_url=BASE_URL,
-        guid=quote_plus(guid).replace('%2f', 'f')
+        guid=re.sub('(?i)\%2f', 'f', quote_plus(guid))
     )
 
 def control():
